# <img src="https://assets.holoviews.org/logo/holoviews_color_icon_500x500.png" alt="HoloViews logo" height="40px" align="left" /> HoloViews

**Stop plotting your data - annotate your data and let it visualize
itself.**

<!-- prettier-ignore -->
|    |    |
| --- | --- |
| Downloads | ![https://pypistats.org/packages/holoviews](https://img.shields.io/pypi/dm/holoviews?label=pypi) ![https://anaconda.org/pyviz/holoviews](https://pyviz.org/_static/cache/holoviews_conda_downloads_badge.svg)
| Build Status | [![Build Status](https://github.com/holoviz/holoviews/actions/workflows/test.yaml/badge.svg?branch=main)](https://github.com/holoviz/holoviews/actions/workflows/test.yaml?query=branch%3Amain) |
| Coverage | [![codecov](https://codecov.io/gh/holoviz/holoviews/branch/main/graph/badge.svg)](https://codecov.io/gh/holoviz/holoviews) |
| Latest dev release | [![Github tag](https://img.shields.io/github/tag/holoviz/holoviews.svg?label=tag&colorB=11ccbb)](https://github.com/holoviz/holoviews/tags) [![dev-site](https://img.shields.io/website-up-down-green-red/http/dev.holoviews.org.svg?label=dev%20website)](https://dev.holoviews.org) |
| Latest release | [![Github release](https://img.shields.io/github/release/holoviz/holoviews.svg?label=tag&colorB=11ccbb)](https://github.com/holoviz/holoviews/releases) [![PyPI version](https://img.shields.io/pypi/v/holoviews.svg?colorB=cc77dd)](https://pypi.python.org/pypi/holoviews) [![holoviews version](https://img.shields.io/conda/v/pyviz/holoviews.svg?colorB=4488ff&style=flat)](https://anaconda.org/pyviz/holoviews) [![conda-forge version](https://img.shields.io/conda/v/conda-forge/holoviews.svg?label=conda%7Cconda-forge&colorB=4488ff)](https://anaconda.org/conda-forge/holoviews) [![defaults version](https://img.shields.io/conda/v/anaconda/holoviews.svg?label=conda%7Cdefaults&style=flat&colorB=4488ff)](https://anaconda.org/anaconda/holoviews) |
| Python | [![Python support](https://img.shields.io/pypi/pyversions/holoviews.svg)](https://pypi.org/project/holoviews/) |
| Docs | [![DocBuildStatus](https://github.com/holoviz/holoviews/workflows/docs/badge.svg?query=branch%3Amain)](https://github.com/holoviz/holoviews/actions?query=workflow%3Adocs+branch%3Amain) [![site](https://img.shields.io/website-up-down-green-red/https/holoviews.org.svg)](https://holoviews.org) |
| Binder | [![Binder](https://img.shields.io/badge/Launch%20JupyterLab-v1.15.4-579ACA.svg?logo=data:image/png;base64, )](https://mybinder.org/v2/gh/holoviz/holoviews/v1.15.4?urlpath=lab/tree/examples) |
| Support | [![Discourse](https://img.shields.io/discourse/status?server=https%3A%2F%2Fdiscourse.holoviz.org)](https://discourse.holoviz.org/) |

HoloViews is an [open-source](https://github.com/holoviz/holoviews/blob/main/LICENSE.txt)
Python library designed to make data analysis and visualization seamless
and simple. With HoloViews, you can usually express what you want to do
in very few lines of code, letting you focus on what you are trying to
explore and convey, not on the process of plotting.

Check out the [HoloViews web site](https://holoviews.org) for extensive examples and documentation.

<div>
<div >
  <a href="https://holoviews.org/gallery/demos/bokeh/iris_splom_example.html">
    <img src="https://holoviews.org/_images/iris_splom_example.png" width='24%'>    </img> </a>
  <a href="https://holoviews.org/getting_started/Gridded_Datasets.html">
    <img src="https://assets.holoviews.org/collage/cells.png" width='27%'> </img>  </a>
  <a href="https://holoviews.org/gallery/demos/bokeh/scatter_economic.html">
    <img src="https://holoviews.org/_images/scatter_economic.png" width='47%' style="height: 350px;object-fit: cover;margin-bottom: 10px;"> </img>    </a>
</div>

<div >
  <a href="https://holoviews.org/gallery/demos/bokeh/square_limit.html">
    <img src="https://holoviews.org/_images/square_limit.png" width='24%'> </a>
  <a href="https://holoviews.org/gallery/demos/bokeh/bars_economic.html">
    <img src="https://holoviews.org/_images/bars_economic.png" width='24%'> </a>
  <a href="https://holoviews.org/gallery/demos/bokeh/texas_choropleth_example.html">
    <img src="https://holoviews.org/_images/texas_choropleth_example.png"    width='24%'> </a>
  <a href="https://holoviews.org/gallery/demos/bokeh/verhulst_mandelbrot.html">
    <img src="https://holoviews.org/_images/verhulst_mandelbrot.png" width='24%'>    </a>
</div>
<div >
    <a href="https://holoviews.org/gallery/demos/bokeh/dropdown_economic.html">
      <img src="https://assets.holoviews.org/collage/dropdown.gif" width='33%'> </a>
    <a href="https://holoviews.org/gallery/demos/bokeh/dragon_curve.html">
      <img src="https://assets.holoviews.org/collage/dragon_fractal.gif" width='30%'> </a>
    <a href="https://holoviews.org/gallery/apps/bokeh/nytaxi_hover.html">
      <img src="https://assets.holoviews.org/collage/ny_datashader.gif" width='33%'> </a>
</div>
</div>

# Installation

HoloViews works with [Python](https://github.com/holoviz/holoviews/actions/workflows/test.yaml)
on Linux, Windows, or Mac, and works seamlessly with [Jupyter Notebook and JupyterLab](https://jupyter.org).

You can install HoloViews either with `conda` or `pip`, for more information see the [install guide](https://holoviews.org/install.html).

    conda install holoviews

    pip install holoviews

# Developer Guide

If you want to help develop HoloViews, you can checkout the [developer guide](https://dev.holoviews.org/developer_guide/index.html),
this guide will help you get set-up. Making it easy to contribute.

# Support & Feedback

If you find any bugs or have any feature suggestions please file a GitHub
[issue](https://github.com/holoviz/holoviews/issues).

If you have any usage questions, please ask them on [HoloViz Discourse](https://discourse.holoviz.org/),

For general discussion, we have a [Discord channel](https://discord.gg/AXRHnJU6sP).
